@@ -4,10 +4,7 @@ Module for monitoring OpenAI API calls.
 
 import time
 from opentelemetry.trace import SpanKind
-from openlit.__helpers import (
-    handle_exception,
-    set_server_address_and_port
-)
+from openlit.__helpers import handle_exception, set_server_address_and_port
 from openlit.instrumentation.openai.utils import (
     process_chat_chunk,
     process_response_chunk,
@@ -21,8 +18,17 @@ from openlit.instrumentation.openai.utils import (
 )
 from openlit.semcov import SemanticConvention
 
-def async_chat_completions(version, environment, application_name, tracer, pricing_info,
-    capture_message_content, metrics, disable_metrics):
+
+def async_chat_completions(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for OpenAI async chat completions.
     """
@@ -33,14 +39,14 @@ def async_chat_completions(version, environment, application_name, tracer, prici
         """
 
         def __init__(
-                self,
-                wrapped,
-                span,
-                span_name,
-                kwargs,
-                server_address,
-                server_port,
-            ):
+            self,
+            wrapped,
+            span,
+            span_name,
+            kwargs,
+            server_address,
+            server_port,
+        ):
             self.__wrapped__ = wrapped
             self._span = span
             self._span_name = span_name
@@ -90,7 +96,7 @@ def async_chat_completions(version, environment, application_name, tracer, prici
                             metrics=metrics,
                             capture_message_content=capture_message_content,
                             disable_metrics=disable_metrics,
-                            version=version
+                            version=version,
                         )
                 except Exception as e:
                     handle_exception(self._span, e)
@@ -102,7 +108,9 @@ def async_chat_completions(version, environment, application_name, tracer, prici
         """
 
         streaming = kwargs.get("stream", False)
-        server_address, server_port = set_server_address_and_port(instance, "api.openai.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.openai.com", 443
+        )
         request_model = kwargs.get("model", "gpt-4o")
 
         span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_CHAT} {request_model}"
@@ -111,7 +119,9 @@ def async_chat_completions(version, environment, application_name, tracer, prici
             awaited_wrapped = await wrapped(*args, **kwargs)
             span = tracer.start_span(span_name, kind=SpanKind.CLIENT)
 
-            return TracedAsyncStream(awaited_wrapped, span, span_name, kwargs, server_address, server_port)
+            return TracedAsyncStream(
+                awaited_wrapped, span, span_name, kwargs, server_address, server_port
+            )
 
         else:
             with tracer.start_as_current_span(span_name, kind=SpanKind.CLIENT) as span:
@@ -121,9 +131,9 @@ def async_chat_completions(version, environment, application_name, tracer, prici
                 try:
                     response = process_chat_response(
                         response=response,
-                            request_model=request_model,
+                        request_model=request_model,
                         pricing_info=pricing_info,
-                            server_port=server_port,
+                        server_port=server_port,
                         server_address=server_address,
                         environment=environment,
                         application_name=application_name,
@@ -133,7 +143,7 @@ def async_chat_completions(version, environment, application_name, tracer, prici
                         capture_message_content=capture_message_content,
                         disable_metrics=disable_metrics,
                         version=version,
-                        **kwargs
+                        **kwargs,
                     )
 
                 except Exception as e:
@@ -143,8 +153,17 @@ def async_chat_completions(version, environment, application_name, tracer, prici
 
     return wrapper
 
-def async_responses(version, environment, application_name, tracer, pricing_info,
-    capture_message_content, metrics, disable_metrics):
+
+def async_responses(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for OpenAI async responses API.
     """
@@ -155,14 +174,14 @@ def async_responses(version, environment, application_name, tracer, pricing_info
         """
 
         def __init__(
-                self,
-                wrapped,
-                span,
-                span_name,
-                kwargs,
-                server_address,
-                server_port,
-            ):
+            self,
+            wrapped,
+            span,
+            span_name,
+            kwargs,
+            server_address,
+            server_port,
+        ):
             self.__wrapped__ = wrapped
             self._span = span
             self._span_name = span_name
@@ -216,7 +235,7 @@ def async_responses(version, environment, application_name, tracer, pricing_info
                             metrics=metrics,
                             capture_message_content=capture_message_content,
                             disable_metrics=disable_metrics,
-                            version=version
+                            version=version,
                         )
                 except Exception as e:
                     handle_exception(self._span, e)
@@ -228,7 +247,9 @@ def async_responses(version, environment, application_name, tracer, pricing_info
         """
 
         streaming = kwargs.get("stream", False)
-        server_address, server_port = set_server_address_and_port(instance, "api.openai.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.openai.com", 443
+        )
         request_model = kwargs.get("model", "gpt-4o")
 
         span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_CHAT} {request_model}"
@@ -237,7 +258,9 @@ def async_responses(version, environment, application_name, tracer, pricing_info
             awaited_wrapped = await wrapped(*args, **kwargs)
             span = tracer.start_span(span_name, kind=SpanKind.CLIENT)
 
-            return TracedAsyncStream(awaited_wrapped, span, span_name, kwargs, server_address, server_port)
+            return TracedAsyncStream(
+                awaited_wrapped, span, span_name, kwargs, server_address, server_port
+            )
 
         else:
             with tracer.start_as_current_span(span_name, kind=SpanKind.CLIENT) as span:
@@ -247,9 +270,9 @@ def async_responses(version, environment, application_name, tracer, pricing_info
                 try:
                     response = process_response_response(
                         response=response,
-                            request_model=request_model,
+                        request_model=request_model,
                         pricing_info=pricing_info,
-                            server_port=server_port,
+                        server_port=server_port,
                         server_address=server_address,
                         environment=environment,
                         application_name=application_name,
@@ -259,7 +282,7 @@ def async_responses(version, environment, application_name, tracer, pricing_info
                         capture_message_content=capture_message_content,
                         disable_metrics=disable_metrics,
                         version=version,
-                        **kwargs
+                        **kwargs,
                     )
 
                 except Exception as e:
@@ -269,8 +292,17 @@ def async_responses(version, environment, application_name, tracer, pricing_info
 
     return wrapper
 
-def async_chat_completions_parse(version, environment, application_name, tracer, pricing_info,
-    capture_message_content, metrics, disable_metrics):
+
+def async_chat_completions_parse(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for OpenAI async chat completions parse.
     """
@@ -280,7 +312,9 @@ def async_chat_completions_parse(version, environment, application_name, tracer,
         Wraps the OpenAI async chat completions parse call.
         """
 
-        server_address, server_port = set_server_address_and_port(instance, "api.openai.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.openai.com", 443
+        )
         request_model = kwargs.get("model", "gpt-4o")
 
         span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_CHAT} {request_model}"
@@ -292,9 +326,9 @@ def async_chat_completions_parse(version, environment, application_name, tracer,
             try:
                 response = process_chat_response(
                     response=response,
-                        request_model=request_model,
+                    request_model=request_model,
                     pricing_info=pricing_info,
-                        server_port=server_port,
+                    server_port=server_port,
                     server_address=server_address,
                     environment=environment,
                     application_name=application_name,
@@ -304,7 +338,7 @@ def async_chat_completions_parse(version, environment, application_name, tracer,
                     capture_message_content=capture_message_content,
                     disable_metrics=disable_metrics,
                     version=version,
-                    **kwargs
+                    **kwargs,
                 )
 
             except Exception as e:
@@ -314,8 +348,17 @@ def async_chat_completions_parse(version, environment, application_name, tracer,
 
     return wrapper
 
-def async_embedding(version, environment, application_name, tracer, pricing_info,
-    capture_message_content, metrics, disable_metrics):
+
+def async_embedding(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for OpenAI async embeddings.
     """
@@ -325,10 +368,14 @@ def async_embedding(version, environment, application_name, tracer, pricing_info
         Wraps the OpenAI async embeddings call.
         """
 
-        server_address, server_port = set_server_address_and_port(instance, "api.openai.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.openai.com", 443
+        )
         request_model = kwargs.get("model", "text-embedding-ada-002")
 
-        span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_EMBEDDING} {request_model}"
+        span_name = (
+            f"{SemanticConvention.GEN_AI_OPERATION_TYPE_EMBEDDING} {request_model}"
+        )
 
         with tracer.start_as_current_span(span_name, kind=SpanKind.CLIENT) as span:
             start_time = time.time()
@@ -337,9 +384,9 @@ def async_embedding(version, environment, application_name, tracer, pricing_info
             try:
                 response = process_embedding_response(
                     response=response,
-                        request_model=request_model,
+                    request_model=request_model,
                     pricing_info=pricing_info,
-                        server_port=server_port,
+                    server_port=server_port,
                     server_address=server_address,
                     environment=environment,
                     application_name=application_name,
@@ -349,7 +396,7 @@ def async_embedding(version, environment, application_name, tracer, pricing_info
                     capture_message_content=capture_message_content,
                     disable_metrics=disable_metrics,
                     version=version,
-                    **kwargs
+                    **kwargs,
                 )
 
             except Exception as e:
@@ -359,8 +406,17 @@ def async_embedding(version, environment, application_name, tracer, pricing_info
 
     return wrapper
 
-def async_image_generate(version, environment, application_name, tracer, pricing_info,
-    capture_message_content, metrics, disable_metrics):
+
+def async_image_generate(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for OpenAI async image generation.
     """
@@ -370,7 +426,9 @@ def async_image_generate(version, environment, application_name, tracer, pricing
         Wraps the OpenAI async image generation call.
         """
 
-        server_address, server_port = set_server_address_and_port(instance, "api.openai.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.openai.com", 443
+        )
         request_model = kwargs.get("model", "dall-e-2")
 
         span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_IMAGE} {request_model}"
@@ -383,9 +441,9 @@ def async_image_generate(version, environment, application_name, tracer, pricing
             try:
                 response = process_image_response(
                     response=response,
-                        request_model=request_model,
+                    request_model=request_model,
                     pricing_info=pricing_info,
-                        server_port=server_port,
+                    server_port=server_port,
                     server_address=server_address,
                     environment=environment,
                     application_name=application_name,
@@ -396,7 +454,7 @@ def async_image_generate(version, environment, application_name, tracer, pricing
                     capture_message_content=capture_message_content,
                     disable_metrics=disable_metrics,
                     version=version,
-                    **kwargs
+                    **kwargs,
                 )
 
             except Exception as e:
@@ -406,8 +464,17 @@ def async_image_generate(version, environment, application_name, tracer, pricing
 
     return wrapper
 
-def async_image_variations(version, environment, application_name, tracer, pricing_info,
-    capture_message_content, metrics, disable_metrics):
+
+def async_image_variations(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for OpenAI async image variations.
     """
@@ -417,7 +484,9 @@ def async_image_variations(version, environment, application_name, tracer, prici
         Wraps the OpenAI async image variations call.
         """
 
-        server_address, server_port = set_server_address_and_port(instance, "api.openai.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.openai.com", 443
+        )
         request_model = kwargs.get("model", "dall-e-2")
 
         span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_IMAGE} {request_model}"
@@ -430,9 +499,9 @@ def async_image_variations(version, environment, application_name, tracer, prici
             try:
                 response = process_image_response(
                     response=response,
-                        request_model=request_model,
+                    request_model=request_model,
                     pricing_info=pricing_info,
-                        server_port=server_port,
+                    server_port=server_port,
                     server_address=server_address,
                     environment=environment,
                     application_name=application_name,
@@ -443,7 +512,7 @@ def async_image_variations(version, environment, application_name, tracer, prici
                     capture_message_content=capture_message_content,
                     disable_metrics=disable_metrics,
                     version=version,
-                    **kwargs
+                    **kwargs,
                 )
 
             except Exception as e:
@@ -453,8 +522,17 @@ def async_image_variations(version, environment, application_name, tracer, prici
 
     return wrapper
 
-def async_audio_create(version, environment, application_name, tracer, pricing_info,
-    capture_message_content, metrics, disable_metrics):
+
+def async_audio_create(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for OpenAI async audio creation.
     """
@@ -464,7 +542,9 @@ def async_audio_create(version, environment, application_name, tracer, pricing_i
         Wraps the OpenAI async audio creation call.
         """
 
-        server_address, server_port = set_server_address_and_port(instance, "api.openai.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.openai.com", 443
+        )
         request_model = kwargs.get("model", "tts-1")
 
         span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_AUDIO} {request_model}"
@@ -477,9 +557,9 @@ def async_audio_create(version, environment, application_name, tracer, pricing_i
             try:
                 response = process_audio_response(
                     response=response,
-                        request_model=request_model,
+                    request_model=request_model,
                     pricing_info=pricing_info,
-                        server_port=server_port,
+                    server_port=server_port,
                     server_address=server_address,
                     environment=environment,
                     application_name=application_name,
@@ -490,7 +570,7 @@ def async_audio_create(version, environment, application_name, tracer, pricing_i
                     capture_message_content=capture_message_content,
                     disable_metrics=disable_metrics,
                     version=version,
-                    **kwargs
+                    **kwargs,
                 )
 
             except Exception as e:
